from django.contrib.auth.models import AbstractUser
from django.db import models


class LdapUser(AbstractUser):
    groups = models.TextField()
    created_at = models.DateField(auto_now_add=True)
    updated_at = models.DateField(auto_now=True)

    def get_setor(self):
        groups_striped = self.groups.replace(" ", "")
        groups = groups_striped.split(",")
        return groups




import sys
import os
from pathlib import Path
from django.conf import settings
from django.core.management import call_command
import django
import pytest

def pytest_configure():
    """
    Configura o Django antes da coleta de testes.
    Isso evita o erro de 'AppRegistryNotReady' durante imports globais.
    """
    base_dir = Path(__file__).resolve().parent
    src_dir = base_dir / "src"
    sys.path.insert(0, str(src_dir))

    if not settings.configured:
        settings.configure(
            DEBUG=True,
            SECRET_KEY='test-secret-key',
            DATABASES={
                'default': {
                    'ENGINE': 'django.db.backends.sqlite3',
                    'NAME': ':memory:',
                }
            },
            INSTALLED_APPS=[
                'django.contrib.auth',
                'django.contrib.contenttypes',
                'django.contrib.admin',
                'django.contrib.messages',
                'ldap_user',
            ],
            AUTH_USER_MODEL='ldap_user.LdapUser',
            
            MIDDLEWARE=[
                'django.contrib.sessions.middleware.SessionMiddleware',
                'django.contrib.auth.middleware.AuthenticationMiddleware',
                'django.contrib.messages.middleware.MessageMiddleware',
            ],
            TEMPLATES=[{
                'BACKEND': 'django.template.backends.django.DjangoTemplates',
                'APP_DIRS': True,
            }],
        )
        django.setup()
        call_command("migrate", verbosity=0)

@pytest.fixture
def user_model():
    from django.contrib.auth import get_user_model
    return get_user_model()


import sys
from pathlib import Path
import django
from django.conf import settings
from django.core.management import execute_from_command_line

BASE_DIR = Path(__file__).resolve().parent
sys.path.insert(0, str(BASE_DIR / "src"))

if __name__ == "__main__":
    if not settings.configured:
        settings.configure(
            DEBUG=True,
            SECRET_KEY='test-secret-key',
            DATABASES={
                'default': {
                    'ENGINE': 'django.db.backends.sqlite3',
                    'NAME': BASE_DIR / 'db.sqlite3',
                }
            },
            INSTALLED_APPS=[
                'django.contrib.auth',
                'django.contrib.contenttypes',
                'ldap_user',
            ],
            AUTH_USER_MODEL='ldap_user.LdapUser',
        )
        django.setup()

    execute_from_command_line(sys.argv)


from ldap_user.models import LdapUser
from django.db.models import Model


def test_is_instance_of_models():
    assert issubclass(LdapUser, Model)


def test_model_has_attributes():
    attributes = [
        "username",
        "first_name",
        "last_name",
        "email",
        "groups",
        "password",
        "created_at",
        "updated_at"
    ]

    for attr in attributes:
        assert hasattr(LdapUser, attr)
        
def test_get_setor():
    user_data = {
        "username": "3222233",
        "first_name": "First",
        "last_name": "Last",
        "email": "first@test.com",
        "groups": "GTI, PCA",
        "password": "0982349"
    }
    user = LdapUser.objects.create(**user_data)
    setor = user.get_setor()
    assert setor == ["GTI", "PCA"]

